@@ -4,7 +4,7 @@ Main interface for codeguru-reviewer service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_codeguru_reviewer import (
         Client,
         CodeGuruReviewerClient,
@@ -13,10 +13,8 @@ Usage::
         RepositoryAssociationSucceededWaiter,
     )
 
-    session = boto3.Session()
-
-    client: CodeGuruReviewerClient = boto3.client("codeguru-reviewer")
-    session_client: CodeGuruReviewerClient = session.client("codeguru-reviewer")
+    session = Session()
+    client: CodeGuruReviewerClient = session.client("codeguru-reviewer")
 
     code_review_completed_waiter: CodeReviewCompletedWaiter = client.get_waiter("code_review_completed")
     repository_association_succeeded_waiter: RepositoryAssociationSucceededWaiter = client.get_waiter("repository_association_succeeded")
