@@ -9,8 +9,8 @@ def print_info() -> None:
     Print package info to stdout.
     """
     print(
-        "Type annotations for boto3.CodeGuruReviewer 1.24.36\nVersion:        "
-        " 1.24.36.post1\nBuilder version: 7.10.0\nDocs:           "
+        "Type annotations for boto3.CodeGuruReviewer 1.24.89\nVersion:         1.24.89\nBuilder"
+        " version: 7.11.10\nDocs:           "
         " https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer//\nBoto3 docs:   "
         "   https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codeguru-reviewer.html#CodeGuruReviewer\nOther"
         " services:  https://pypi.org/project/boto3-stubs/\nChangelog:      "
@@ -22,7 +22,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("1.24.36.post1")
+    print("1.24.89")
 
 
 def main() -> None:
